@@ -46,10 +46,6 @@ public:
 
 private:
     Q_DECLARE_PRIVATE(KFontAction)
-#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 79)
-    // Unused, kept for ABI compatibility
-    const void *__kwidgetsaddons_d_do_not_use;
-#endif
 };
 
 #endif
