@@ -45,11 +45,11 @@ void showResult(int test, int i)
     case KMessageBox::Cancel:
         printf("(%s)\n", "Cancel");
         break;
-    case KMessageBox::Yes:
-        printf("(%s)\n", "Yes");
+    case KMessageBox::PrimaryAction:
+        printf("(%s)\n", "PrimaryAction");
         break;
-    case KMessageBox::No:
-        printf("(%s)\n", "No");
+    case KMessageBox::SecondaryAction:
+        printf("(%s)\n", "SecondaryAction");
         break;
     case KMessageBox::Continue:
         printf("(%s)\n", "Continue");
@@ -87,99 +87,73 @@ bool testMessageBox(int test)
                                                KStandardGuiItem::cancel(),
                                                QStringLiteral("dontask"),
                                                KMessageBox::AllowLink);
-        i = KMessageBox::questionYesNo(nullptr,
-                                       QStringLiteral("<p>Do you have a printer? thisisaverylongdkldhklghklghklashgkllasghkdlsghkldfghklsabla bla bbla bla. It "
-                                                      "also has <a href=http://www.kde.org>this URL</a>.</p>"),
-                                       QStringLiteral("Bla"),
-                                       KGuiItem(QStringLiteral("Yes")),
-                                       KGuiItem(QStringLiteral("No")),
-                                       QStringLiteral("bla"),
-                                       KMessageBox::AllowLink);
+        i = KMessageBox::questionTwoActions(
+            nullptr,
+            QStringLiteral("<p>Do you have a printer? thisisaverylongdkldhklghklghklashgkllasghkdlsghkldfghklsabla bla bbla bla. It "
+                           "also has <a href=http://www.kde.org>this URL</a>.</p>"),
+            QStringLiteral("Bla"),
+            KGuiItem(QStringLiteral("Scan")),
+            KGuiItem(QStringLiteral("Select")),
+            QStringLiteral("bla"),
+            KMessageBox::AllowLink);
         break;
     }
     case 2:
-        i = KMessageBox::questionYesNo(nullptr, QStringLiteral("Do you have a printer?"), QStringLiteral("Printer setup"));
+        i = KMessageBox::questionTwoActions(nullptr,
+                                            QStringLiteral("Does your printer support color or only black and white?"),
+                                            QStringLiteral("Printer setup"),
+                                            KGuiItem(QStringLiteral("Print Color")),
+                                            KGuiItem(QLatin1String("Print Black & White")));
         break;
-
     case 3:
-        i = KMessageBox::questionYesNo(nullptr,
-                                       QStringLiteral("Does your printer support color or only black and white?"),
-                                       QStringLiteral("Printer setup"),
-                                       KGuiItem(QStringLiteral("&Color")),
-                                       KGuiItem(QLatin1String("&Black & White")));
+        i = KMessageBox::warningTwoActions(nullptr,
+                                           QStringLiteral("Your printer has been added.\n"
+                                                          "Do you want to update your configuration?"),
+                                           QStringLiteral("Printer Setup"),
+                                           KGuiItem(QStringLiteral("Update")),
+                                           KGuiItem(QStringLiteral("Skip")));
         break;
 
     case 4:
-        i = KMessageBox::warningYesNo(nullptr,
-                                      QString::fromLatin1("KDVI could not locate the program 'dvipdfm' on your computer. That program is "
-                                                          "absolutely needed by the export function. You can, however, convert "
-                                                          "the DVI-file to PDF using the print function of KDVI, but that will often "
-                                                          "produce files which print ok, but are of inferior quality if viewed in the "
-                                                          "Acrobat Reader. It may be wise to upgrade to a more recent version of your "
-                                                          "TeX distribution which includes the 'dvipdfm' program.\n"
-                                                          "Hint to the perplexed system administrator: KDVI uses the shell's PATH variable "
-                                                          "when looking for programs."));
-        break;
-
-    case 5:
-        i = KMessageBox::warningYesNo(nullptr,
-                                      QString::fromLatin1("Your printer has been added.\n"
-                                                          "Do you want to update your configuration?"),
-                                      QStringLiteral("Printer Setup"));
-        break;
-
-    case 6:
         i = KMessageBox::warningContinueCancel(nullptr,
                                                QString::fromLatin1("You are about to print.\n"
                                                                    "Are you sure?"),
                                                QStringLiteral("Print"),
                                                KGuiItem(QStringLiteral("&Print")));
         break;
+
+    case 5:
+        i = KMessageBox::warningContinueCancel(nullptr,
+                                               QString::fromLatin1("You are about to <Print>.\n"
+                                                                   "Are you sure?"),
+                                               QStringLiteral("Print"),
+                                               KGuiItem(QStringLiteral("&Print")),
+                                               KStandardGuiItem::cancel(),
+                                               QStringLiteral("dontask"));
+        i = KMessageBox::warningContinueCancel(nullptr,
+                                               QString::fromLatin1("You are about to <Print>.\n"
+                                                                   "Are you sure?"),
+                                               QStringLiteral("Print"),
+                                               KGuiItem(QStringLiteral("&Print")),
+                                               KStandardGuiItem::cancel(),
+                                               QStringLiteral("dontask"));
+        break;
+
+    case 6:
+        i = KMessageBox::warningTwoActionsCancel(nullptr,
+                                                 QString::fromLatin1("Your document contains unsaved changes.\n"
+                                                                     "Do you want to save or discard your changes?\n"),
+                                                 QStringLiteral("Close"),
+                                                 KGuiItem(QStringLiteral("&Save")),
+                                                 KGuiItem(QStringLiteral("&Discard")));
+        break;
+
     case 7:
-        i = KMessageBox::warningContinueCancel(nullptr,
-                                               QString::fromLatin1("You are about to <Print>.\n"
-                                                                   "Are you sure?"),
-                                               QStringLiteral("Print"),
-                                               KGuiItem(QStringLiteral("&Print")),
-                                               KStandardGuiItem::cancel(),
-                                               QStringLiteral("dontask"));
-        i = KMessageBox::warningContinueCancel(nullptr,
-                                               QString::fromLatin1("You are about to <Print>.\n"
-                                                                   "Are you sure?"),
-                                               QStringLiteral("Print"),
-                                               KGuiItem(QStringLiteral("&Print")),
-                                               KStandardGuiItem::cancel(),
-                                               QStringLiteral("dontask"));
-        break;
-
-    case 8:
-        i = KMessageBox::warningYesNoCancel(nullptr,
-                                            QString::fromLatin1("Your document contains unsaved changes.\n"
-                                                                "Do you want to save your changes?\n"));
-        break;
-
-    case 9:
-        i = KMessageBox::warningYesNoCancel(nullptr,
-                                            QString::fromLatin1("Your document contains unsaved changes.\n"
-                                                                "Do you want to save your changes?\n"),
-                                            QStringLiteral("Close"));
-        break;
-
-    case 10:
-        i = KMessageBox::warningYesNoCancel(nullptr,
-                                            QString::fromLatin1("Your document contains unsaved changes.\n"
-                                                                "Do you want to save or discard your changes?\n"),
-                                            QStringLiteral("Close"),
-                                            KGuiItem(QStringLiteral("&Save")),
-                                            KGuiItem(QStringLiteral("&Discard")));
-        break;
-
-    case 11:
         i = KMessageBox::Ok;
         KMessageBox::error(nullptr, QStringLiteral("Oops, Your harddisk is unreadable."));
         break;
 
-    case 12:
+    case 8:
         i = KMessageBox::Ok;
         KMessageBox::detailedError(nullptr,
                                    QStringLiteral("Oops, Your harddisk is unreadable."),
@@ -187,28 +161,14 @@ bool testMessageBox(int test)
                                    QStringLiteral("Uh ooh"));
         break;
 
-    case 13:
-        i = KMessageBox::Ok;
-        KMessageBox::sorry(nullptr, QStringLiteral("Sorry, Your harddisk appears to be empty."), QString(), KGuiItem(QStringLiteral("Abort")));
-        break;
-
-    case 14:
-        i = KMessageBox::Ok;
-        KMessageBox::detailedSorry(nullptr,
-                                   QStringLiteral("Sorry, Your harddisk appears to be empty."),
-                                   QStringLiteral("We don't know more yet."),
-                                   QStringLiteral("Oops"),
-                                   KGuiItem(QStringLiteral("Abort")));
-        break;
-
-    case 15:
+    case 9:
         i = KMessageBox::Ok;
         KMessageBox::information(nullptr,
                                  QString::fromLatin1("You can enable the menubar again "
                                                      "with the right mouse button menu."));
         break;
 
-    case 16:
+    case 10:
         i = KMessageBox::Ok;
         KMessageBox::information(nullptr,
                                  QString::fromLatin1("You can enable the menubar again "
@@ -216,7 +176,7 @@ bool testMessageBox(int test)
                                  QStringLiteral("Menubar Info"));
         break;
 
-    case 17:
+    case 11:
         i = KMessageBox::Ok;
         KMessageBox::information(nullptr,
                                  QStringLiteral("You can enable the menubar again\nwith the right mouse button menu."),
@@ -224,16 +184,16 @@ bool testMessageBox(int test)
                                  QStringLiteral("Enable_Menubar"));
         break;
 
-    case 18:
+    case 12:
         i = KMessageBox::Ok;
         KMessageBox::enableAllMessages();
         break;
 
-    case 19:
+    case 13:
         i = KMessageBox::Ok;
         KMessageBox::information(nullptr, QStringLiteral("Return of the annoying popup message."), QString(), QStringLiteral("Enable_Menubar"));
         break;
-    case 20: {
+    case 14: {
         QStringList strlist;
         strlist << QStringLiteral("/dev/hda") << QStringLiteral("/etc/inittab") << QStringLiteral("/usr/somefile")
                 << QString::fromLatin1(
@@ -241,43 +201,43 @@ bool testMessageBox(int test)
                        "long/file/name/which/is/in/a/really/deep/directory/in/a/really/large/"
                        "hard/disk/of/your/system")
                 << QStringLiteral("/and/another/one");
-        i = KMessageBox::questionYesNoList(nullptr, QStringLiteral("Do you want to delete the following files?"), strlist);
+        i = KMessageBox::questionTwoActionsList(nullptr,
+                                                QStringLiteral("Do you want to delete the following files?"),
+                                                strlist,
+                                                QStringLiteral("Delete Files"),
+                                                KGuiItem(QStringLiteral("Delete")),
+                                                KGuiItem(QStringLiteral("Move to Trash")));
     } break;
-    case 21: {
+    case 15: {
         QStringList strlist;
         printf("Filling StringList...\n");
         for (int j = 1; j <= 6000; j++) {
             strlist.append(QStringLiteral("/tmp/tmp.%1").arg(j));
         }
         printf("Completed...\n");
-        i = KMessageBox::questionYesNoList(nullptr, QStringLiteral("Do you want to delete the following files?"), strlist);
+        i = KMessageBox::questionTwoActionsList(nullptr,
+                                                QStringLiteral("Do you want to delete the following files?"),
+                                                strlist,
+                                                QStringLiteral("Delete Files"),
+                                                KGuiItem(QStringLiteral("Delete")),
+                                                KGuiItem(QStringLiteral("Move to Trash")));
     } break;
 
-    case 22:
+    case 16:
         i = KMessageBox::Ok;
         KMessageBox::informationList(nullptr, QStringLiteral("The following words have been found:"), list);
         break;
 
-    case 23:
+    case 17:
         i = KMessageBox::Ok;
         KMessageBox::informationList(nullptr, QStringLiteral("The following words have been found:"), list, QStringLiteral("Search Words"));
         break;
 
-    case 24:
+    case 18:
         i = KMessageBox::Ok;
         KMessageBox::informationList(nullptr, QStringLiteral("The following words have been found:"), list, QString(), QStringLiteral("Search_Words"));
         break;
 
-    case 25: {
-        i = KMessageBox::Ok;
-        QString msg;
-        for (int j = 0; j < 200; ++j) {
-            msg.append("LongMessageWithoutAnyBreaksShouldAppearSqueezed.");
-        }
-        KMessageBox::sorry(nullptr, msg);
-        break;
-    }
-
     default:
         return false; // done
     } // Switch
@@ -289,7 +249,6 @@ bool testMessageBox(int test)
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
-    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
     app.setApplicationName(QStringLiteral("kmessageboxtest"));
 
     // Syntax: kmessageboxtest <test_number>
